function [x_s, u_s] = getSteadyStateWithDisturbanceModel(A, B, B_d, C, C_d, Q_s, R_s, y_ref, H, r_ref, d_est)

    [nx, nu] = size(B);
    ny = size(y_ref, 1);
    nc = size(r_ref, 1);
    
    % Define Aeq (see documentation of fmincon)
    Aeq = zeros(nx+nc, nx+nu);
    
    beq = zeros(nx+nc,1);
    
    Aeq(1:nx, 1:nx) = eye(nx)-A;
    Aeq(1:nx, nx+1:nx+nu) = -B;
    Aeq(nx+1:nx+nc, 1:nx) = H*C;
    
    beq(1:nx, 1) = B_d*d_est;
    beq(nx+1:end, 1) = r_ref - H*C_d*d_est;
    
    cost = @(z) (C*z(1:nx)+C_d*d_est-y_ref)'*Q_s*(C*z(1:nx)+C_d*d_est-y_ref) + ...
                z(nx+1:end)'*R_s*z(nx+1:end,1);
            
    Z0 = zeros(nx+nu,1);

    options = optimoptions('fmincon','Display','iter','Algorithm','active-set');
    z_opt = fmincon(cost,Z0,[],[],Aeq,beq,[],[],[],options);
    
    x_s = z_opt(1:nx);
    u_s = z_opt(nx+1:end);
end


